/****************************************************************************
** Meta object code from reading C++ file 'qsynthMainForm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qsynth-1.0.6/src/qsynthMainForm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsynthMainForm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14qsynthMainFormE_t {};
} // unnamed namespace

template <> constexpr inline auto qsynthMainForm::qt_create_metaobjectdata<qt_meta_tag_ZN14qsynthMainFormE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qsynthMainForm",
        "stdoutNotifySlot",
        "",
        "sigtermNotifySlot",
        "programReset",
        "systemReset",
        "promptRestart",
        "newEngine",
        "deleteEngine",
        "toggleMainForm",
        "toggleMessagesForm",
        "toggleChannelsForm",
        "showSetupForm",
        "showOptionsForm",
        "showAboutForm",
        "tabSelect",
        "tabContextMenu",
        "QPoint",
        "timerSlot",
        "reverbActivate",
        "chorusActivate",
        "gainChanged",
        "reverbChanged",
        "chorusChanged",
        "activateEnginesMenu",
        "QAction*",
        "quitMainForm",
        "commitData",
        "QSessionManager&",
        "sm"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'stdoutNotifySlot'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'sigtermNotifySlot'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'programReset'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'systemReset'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'promptRestart'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'newEngine'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteEngine'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleMainForm'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleMessagesForm'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleChannelsForm'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showSetupForm'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showOptionsForm'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showAboutForm'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tabSelect'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'tabContextMenu'
        QtMocHelpers::SlotData<void(int, const QPoint &)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 17, 2 },
        }}),
        // Slot 'timerSlot'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'reverbActivate'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'chorusActivate'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'gainChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'reverbChanged'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'chorusChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'activateEnginesMenu'
        QtMocHelpers::SlotData<void(QAction *)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
        // Slot 'quitMainForm'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'commitData'
        QtMocHelpers::SlotData<void(QSessionManager &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<qsynthMainForm, qt_meta_tag_ZN14qsynthMainFormE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qsynthMainForm::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14qsynthMainFormE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14qsynthMainFormE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14qsynthMainFormE_t>.metaTypes,
    nullptr
} };

void qsynthMainForm::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<qsynthMainForm *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stdoutNotifySlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->sigtermNotifySlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->programReset(); break;
        case 3: _t->systemReset(); break;
        case 4: _t->promptRestart(); break;
        case 5: _t->newEngine(); break;
        case 6: _t->deleteEngine(); break;
        case 7: _t->toggleMainForm(); break;
        case 8: _t->toggleMessagesForm(); break;
        case 9: _t->toggleChannelsForm(); break;
        case 10: _t->showSetupForm(); break;
        case 11: _t->showOptionsForm(); break;
        case 12: _t->showAboutForm(); break;
        case 13: _t->tabSelect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->tabContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 15: _t->timerSlot(); break;
        case 16: _t->reverbActivate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->chorusActivate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->gainChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->reverbChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->chorusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->activateEnginesMenu((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 22: _t->quitMainForm(); break;
        case 23: _t->commitData((*reinterpret_cast<std::add_pointer_t<QSessionManager&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *qsynthMainForm::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qsynthMainForm::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14qsynthMainFormE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int qsynthMainForm::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
