// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_qsynth.cpp"
#include "EWIEGA46WW/moc_qsynthAboutForm.cpp"
#include "EWIEGA46WW/moc_qsynthChannelsForm.cpp"
#include "EWIEGA46WW/moc_qsynthKnob.cpp"
#include "EWIEGA46WW/moc_qsynthMainForm.cpp"
#include "EWIEGA46WW/moc_qsynthMessagesForm.cpp"
#include "EWIEGA46WW/moc_qsynthMeter.cpp"
#include "EWIEGA46WW/moc_qsynthOptionsForm.cpp"
#include "EWIEGA46WW/moc_qsynthPaletteForm.cpp"
#include "EWIEGA46WW/moc_qsynthPresetForm.cpp"
#include "EWIEGA46WW/moc_qsynthSetupForm.cpp"
#include "EWIEGA46WW/moc_qsynthSystemTray.cpp"
#include "EWIEGA46WW/moc_qsynthTabBar.cpp"
