/*
qsynth - A fluidsynth Qt GUI Interface.

   Copyright (C) 2003-2025, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qsynthAboutForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSYNTHABOUTFORM_H
#define UI_QSYNTHABOUTFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>

QT_BEGIN_NAMESPACE

class Ui_qsynthAboutForm
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QPushButton *ClosePushButton;
    QToolButton *AboutQtButton;
    QSpacerItem *spacerItem1;
    QTextBrowser *AboutTextView;
    QLabel *IconPixmapLabel;

    void setupUi(QDialog *qsynthAboutForm)
    {
        if (qsynthAboutForm->objectName().isEmpty())
            qsynthAboutForm->setObjectName("qsynthAboutForm");
        qsynthAboutForm->resize(520, 280);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/about1.png"));
        qsynthAboutForm->setWindowIcon(icon);
        qsynthAboutForm->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(qsynthAboutForm);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(4, 4, 4, 4);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(8, 8, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 2, 2, 1, 1);

        ClosePushButton = new QPushButton(qsynthAboutForm);
        ClosePushButton->setObjectName("ClosePushButton");

        gridLayout->addWidget(ClosePushButton, 2, 1, 1, 1);

        AboutQtButton = new QToolButton(qsynthAboutForm);
        AboutQtButton->setObjectName("AboutQtButton");
        AboutQtButton->setFocusPolicy(Qt::TabFocus);
        const QIcon icon1 = QIcon(QString::fromUtf8(":/images/qtlogo1.png"));
        AboutQtButton->setIcon(icon1);

        gridLayout->addWidget(AboutQtButton, 2, 0, 1, 1);

        spacerItem1 = new QSpacerItem(8, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 1, 0, 1, 1);

        AboutTextView = new QTextBrowser(qsynthAboutForm);
        AboutTextView->setObjectName("AboutTextView");
        AboutTextView->setLineWidth(1);
        AboutTextView->setUndoRedoEnabled(false);
        AboutTextView->setReadOnly(true);
        AboutTextView->setOpenExternalLinks(true);

        gridLayout->addWidget(AboutTextView, 0, 1, 2, 2);

        IconPixmapLabel = new QLabel(qsynthAboutForm);
        IconPixmapLabel->setObjectName("IconPixmapLabel");
        IconPixmapLabel->setMaximumSize(QSize(32, 32));
        IconPixmapLabel->setPixmap(QPixmap(QString::fromUtf8(":/images/qsynth.svg")));
        IconPixmapLabel->setScaledContents(true);
        IconPixmapLabel->setAlignment(Qt::AlignCenter);
        IconPixmapLabel->setWordWrap(false);
        IconPixmapLabel->setMargin(2);

        gridLayout->addWidget(IconPixmapLabel, 0, 0, 1, 1);

        QWidget::setTabOrder(AboutTextView, AboutQtButton);
        QWidget::setTabOrder(AboutQtButton, ClosePushButton);

        retranslateUi(qsynthAboutForm);

        QMetaObject::connectSlotsByName(qsynthAboutForm);
    } // setupUi

    void retranslateUi(QDialog *qsynthAboutForm)
    {
        qsynthAboutForm->setWindowTitle(QCoreApplication::translate("qsynthAboutForm", "About", nullptr));
        ClosePushButton->setText(QCoreApplication::translate("qsynthAboutForm", "&Close", nullptr));
#if QT_CONFIG(tooltip)
        AboutQtButton->setToolTip(QCoreApplication::translate("qsynthAboutForm", "About Qt", nullptr));
#endif // QT_CONFIG(tooltip)
        AboutQtButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class qsynthAboutForm: public Ui_qsynthAboutForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSYNTHABOUTFORM_H
