/*
qsynth - A fluidsunth Qt GUI Interface.

   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qsynthMessagesForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSYNTHMESSAGESFORM_H
#define UI_QSYNTHMESSAGESFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qsynthMessagesForm
{
public:
    QGridLayout *gridLayout;
    QTextBrowser *MessagesTextView;

    void setupUi(QWidget *qsynthMessagesForm)
    {
        if (qsynthMessagesForm->objectName().isEmpty())
            qsynthMessagesForm->setObjectName("qsynthMessagesForm");
        qsynthMessagesForm->resize(520, 240);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/messages1.png"));
        qsynthMessagesForm->setWindowIcon(icon);
        gridLayout = new QGridLayout(qsynthMessagesForm);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(4, 4, 4, 4);
        gridLayout->setObjectName("gridLayout");
        MessagesTextView = new QTextBrowser(qsynthMessagesForm);
        MessagesTextView->setObjectName("MessagesTextView");
        MessagesTextView->setMinimumSize(QSize(320, 80));
        MessagesTextView->setLineWrapMode(QTextEdit::NoWrap);
        MessagesTextView->setReadOnly(true);
        MessagesTextView->setUndoRedoEnabled(false);

        gridLayout->addWidget(MessagesTextView, 0, 0, 1, 1);


        retranslateUi(qsynthMessagesForm);

        QMetaObject::connectSlotsByName(qsynthMessagesForm);
    } // setupUi

    void retranslateUi(QWidget *qsynthMessagesForm)
    {
        qsynthMessagesForm->setWindowTitle(QCoreApplication::translate("qsynthMessagesForm", "Messages", nullptr));
#if QT_CONFIG(tooltip)
        MessagesTextView->setToolTip(QCoreApplication::translate("qsynthMessagesForm", "Messages output log", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class qsynthMessagesForm: public Ui_qsynthMessagesForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSYNTHMESSAGESFORM_H
