/*
qsynth - A fluidsynth Qt GUI Interface.

   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qsynthPresetForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSYNTHPRESETFORM_H
#define UI_QSYNTHPRESETFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qsynthPresetForm
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *DialogButtonBox;
    QTabWidget *PresetTabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout;
    QSplitter *splitter1;
    QTreeWidget *BankListView;
    QTreeWidget *ProgListView;
    QCheckBox *PreviewCheckBox;

    void setupUi(QDialog *qsynthPresetForm)
    {
        if (qsynthPresetForm->objectName().isEmpty())
            qsynthPresetForm->setObjectName("qsynthPresetForm");
        qsynthPresetForm->resize(520, 320);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/preset1.png"));
        qsynthPresetForm->setWindowIcon(icon);
        qsynthPresetForm->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(qsynthPresetForm);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        DialogButtonBox = new QDialogButtonBox(qsynthPresetForm);
        DialogButtonBox->setObjectName("DialogButtonBox");
        DialogButtonBox->setOrientation(Qt::Horizontal);
        DialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(DialogButtonBox, 1, 0, 1, 1);

        PresetTabWidget = new QTabWidget(qsynthPresetForm);
        PresetTabWidget->setObjectName("PresetTabWidget");
        PresetTabWidget->setTabShape(QTabWidget::Rounded);
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout = new QVBoxLayout(tab);
        vboxLayout->setSpacing(4);
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        splitter1 = new QSplitter(tab);
        splitter1->setObjectName("splitter1");
        splitter1->setOrientation(Qt::Horizontal);
        BankListView = new QTreeWidget(splitter1);
        BankListView->setObjectName("BankListView");
        BankListView->setMinimumSize(QSize(20, 0));
        BankListView->setMaximumSize(QSize(80, 32767));
        BankListView->setAlternatingRowColors(true);
        BankListView->setIndentation(4);
        BankListView->setRootIsDecorated(false);
        BankListView->setUniformRowHeights(true);
        BankListView->setItemsExpandable(false);
        BankListView->setSortingEnabled(true);
        BankListView->setAllColumnsShowFocus(true);
        splitter1->addWidget(BankListView);
        ProgListView = new QTreeWidget(splitter1);
        ProgListView->setObjectName("ProgListView");
        ProgListView->setAlternatingRowColors(true);
        ProgListView->setIndentation(4);
        ProgListView->setRootIsDecorated(false);
        ProgListView->setUniformRowHeights(true);
        ProgListView->setItemsExpandable(false);
        ProgListView->setSortingEnabled(true);
        ProgListView->setAllColumnsShowFocus(true);
        splitter1->addWidget(ProgListView);

        vboxLayout->addWidget(splitter1);

        PreviewCheckBox = new QCheckBox(tab);
        PreviewCheckBox->setObjectName("PreviewCheckBox");

        vboxLayout->addWidget(PreviewCheckBox);

        PresetTabWidget->addTab(tab, QString());

        gridLayout->addWidget(PresetTabWidget, 0, 0, 1, 1);

        QWidget::setTabOrder(PresetTabWidget, BankListView);
        QWidget::setTabOrder(BankListView, ProgListView);
        QWidget::setTabOrder(ProgListView, PreviewCheckBox);
        QWidget::setTabOrder(PreviewCheckBox, DialogButtonBox);

        retranslateUi(qsynthPresetForm);

        QMetaObject::connectSlotsByName(qsynthPresetForm);
    } // setupUi

    void retranslateUi(QDialog *qsynthPresetForm)
    {
        qsynthPresetForm->setWindowTitle(QCoreApplication::translate("qsynthPresetForm", "Channel Preset", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = BankListView->headerItem();
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("qsynthPresetForm", "Bank", nullptr));
#if QT_CONFIG(tooltip)
        BankListView->setToolTip(QCoreApplication::translate("qsynthPresetForm", "Bank selector", nullptr));
#endif // QT_CONFIG(tooltip)
        QTreeWidgetItem *___qtreewidgetitem1 = ProgListView->headerItem();
        ___qtreewidgetitem1->setText(3, QCoreApplication::translate("qsynthPresetForm", "Soundfont", nullptr));
        ___qtreewidgetitem1->setText(2, QCoreApplication::translate("qsynthPresetForm", "SFID", nullptr));
        ___qtreewidgetitem1->setText(1, QCoreApplication::translate("qsynthPresetForm", "Name", nullptr));
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("qsynthPresetForm", "Prog", nullptr));
#if QT_CONFIG(tooltip)
        ProgListView->setToolTip(QCoreApplication::translate("qsynthPresetForm", "Program selector", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        PreviewCheckBox->setToolTip(QCoreApplication::translate("qsynthPresetForm", "Whether to preview the current selection", nullptr));
#endif // QT_CONFIG(tooltip)
        PreviewCheckBox->setText(QCoreApplication::translate("qsynthPresetForm", "Preview", nullptr));
#if QT_CONFIG(shortcut)
        PreviewCheckBox->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        PresetTabWidget->setTabText(PresetTabWidget->indexOf(tab), QCoreApplication::translate("qsynthPresetForm", "Preset", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qsynthPresetForm: public Ui_qsynthPresetForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSYNTHPRESETFORM_H
