/*
qsynth - A fluidsynth Qt GUI Interface.

   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qsynthChannelsForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSYNTHCHANNELSFORM_H
#define UI_QSYNTHCHANNELSFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qsynthChannelsForm
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *PresetTextLabel;
    QComboBox *PresetComboBox;
    QPushButton *PresetSavePushButton;
    QPushButton *PresetDeletePushButton;
    QTreeWidget *ChannelsListView;

    void setupUi(QWidget *qsynthChannelsForm)
    {
        if (qsynthChannelsForm->objectName().isEmpty())
            qsynthChannelsForm->setObjectName("qsynthChannelsForm");
        qsynthChannelsForm->resize(520, 320);
        QFont font;
        qsynthChannelsForm->setFont(font);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/channels1.png"));
        qsynthChannelsForm->setWindowIcon(icon);
        vboxLayout = new QVBoxLayout(qsynthChannelsForm);
        vboxLayout->setSpacing(4);
        vboxLayout->setContentsMargins(4, 4, 4, 4);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(4);
        hboxLayout->setContentsMargins(4, 4, 4, 4);
        hboxLayout->setObjectName("hboxLayout");
        PresetTextLabel = new QLabel(qsynthChannelsForm);
        PresetTextLabel->setObjectName("PresetTextLabel");
        PresetTextLabel->setWordWrap(false);

        hboxLayout->addWidget(PresetTextLabel);

        PresetComboBox = new QComboBox(qsynthChannelsForm);
        PresetComboBox->addItem(QString());
        PresetComboBox->setObjectName("PresetComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PresetComboBox->sizePolicy().hasHeightForWidth());
        PresetComboBox->setSizePolicy(sizePolicy);
        PresetComboBox->setEditable(true);

        hboxLayout->addWidget(PresetComboBox);

        PresetSavePushButton = new QPushButton(qsynthChannelsForm);
        PresetSavePushButton->setObjectName("PresetSavePushButton");
        const QIcon icon1 = QIcon(QString::fromUtf8(":/images/save1.png"));
        PresetSavePushButton->setIcon(icon1);
        PresetSavePushButton->setAutoDefault(false);

        hboxLayout->addWidget(PresetSavePushButton);

        PresetDeletePushButton = new QPushButton(qsynthChannelsForm);
        PresetDeletePushButton->setObjectName("PresetDeletePushButton");
        const QIcon icon2 = QIcon(QString::fromUtf8(":/images/remove1.png"));
        PresetDeletePushButton->setIcon(icon2);
        PresetDeletePushButton->setAutoDefault(false);

        hboxLayout->addWidget(PresetDeletePushButton);


        vboxLayout->addLayout(hboxLayout);

        ChannelsListView = new QTreeWidget(qsynthChannelsForm);
        ChannelsListView->setObjectName("ChannelsListView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ChannelsListView->sizePolicy().hasHeightForWidth());
        ChannelsListView->setSizePolicy(sizePolicy1);
        ChannelsListView->setMinimumSize(QSize(320, 0));
        ChannelsListView->setContextMenuPolicy(Qt::CustomContextMenu);
        ChannelsListView->setAlternatingRowColors(true);
        ChannelsListView->setIndentation(4);
        ChannelsListView->setRootIsDecorated(false);
        ChannelsListView->setUniformRowHeights(true);
        ChannelsListView->setItemsExpandable(false);
        ChannelsListView->setSortingEnabled(true);
        ChannelsListView->setAllColumnsShowFocus(true);

        vboxLayout->addWidget(ChannelsListView);

#if QT_CONFIG(shortcut)
        PresetTextLabel->setBuddy(PresetComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(PresetComboBox, PresetSavePushButton);
        QWidget::setTabOrder(PresetSavePushButton, PresetDeletePushButton);
        QWidget::setTabOrder(PresetDeletePushButton, ChannelsListView);

        retranslateUi(qsynthChannelsForm);

        QMetaObject::connectSlotsByName(qsynthChannelsForm);
    } // setupUi

    void retranslateUi(QWidget *qsynthChannelsForm)
    {
        qsynthChannelsForm->setWindowTitle(QCoreApplication::translate("qsynthChannelsForm", "Channels", nullptr));
        PresetTextLabel->setText(QCoreApplication::translate("qsynthChannelsForm", "Preset &Name:", nullptr));
        PresetComboBox->setItemText(0, QCoreApplication::translate("qsynthChannelsForm", "(default)", nullptr));

#if QT_CONFIG(tooltip)
        PresetComboBox->setToolTip(QCoreApplication::translate("qsynthChannelsForm", "Settings preset name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        PresetSavePushButton->setToolTip(QCoreApplication::translate("qsynthChannelsForm", "Save settings as current preset name", nullptr));
#endif // QT_CONFIG(tooltip)
        PresetSavePushButton->setText(QCoreApplication::translate("qsynthChannelsForm", "&Save", nullptr));
#if QT_CONFIG(tooltip)
        PresetDeletePushButton->setToolTip(QCoreApplication::translate("qsynthChannelsForm", "Delete current settings preset", nullptr));
#endif // QT_CONFIG(tooltip)
        PresetDeletePushButton->setText(QCoreApplication::translate("qsynthChannelsForm", "&Delete", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = ChannelsListView->headerItem();
        ___qtreewidgetitem->setText(6, QCoreApplication::translate("qsynthChannelsForm", "Soundfont", nullptr));
        ___qtreewidgetitem->setText(5, QCoreApplication::translate("qsynthChannelsForm", "SFID", nullptr));
        ___qtreewidgetitem->setText(4, QCoreApplication::translate("qsynthChannelsForm", "Name", nullptr));
        ___qtreewidgetitem->setText(3, QCoreApplication::translate("qsynthChannelsForm", "Prog", nullptr));
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("qsynthChannelsForm", "Bank", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("qsynthChannelsForm", "Chan", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("qsynthChannelsForm", "In", nullptr));
#if QT_CONFIG(tooltip)
        ChannelsListView->setToolTip(QCoreApplication::translate("qsynthChannelsForm", "Channels view", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class qsynthChannelsForm: public Ui_qsynthChannelsForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSYNTHCHANNELSFORM_H
