/*
qsynth - A fluidsynth Qt GUI Interface.

   Copyright (C) 2003-2026, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qsynthOptionsForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSYNTHOPTIONSFORM_H
#define UI_QSYNTHOPTIONSFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qsynthOptionsForm
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *OptionsTabWidget;
    QWidget *GeneralTabPage;
    QVBoxLayout *vboxLayout1;
    QGroupBox *MessagesGroupBox;
    QHBoxLayout *hboxLayout;
    QLabel *MessagesFontTextLabel;
    QPushButton *MessagesFontPushButton;
    QSpacerItem *spacerItem;
    QCheckBox *MessagesLimitCheckBox;
    QComboBox *MessagesLimitLinesComboBox;
    QGroupBox *LoggingGroupBox;
    QGridLayout *gridLayout;
    QComboBox *MessagesLogPathComboBox;
    QToolButton *MessagesLogPathToolButton;
    QCheckBox *MessagesLogCheckBox;
    QGroupBox *OtherGroupBox;
    QGridLayout *gridLayout1;
    QCheckBox *QueryCloseCheckBox;
    QCheckBox *KeepOnTopCheckBox;
    QCheckBox *StdoutCaptureCheckBox;
    QCheckBox *OutputMetersCheckBox;
    QSpacerItem *spacerItem1;
    QCheckBox *SystemTrayCheckBox;
    QCheckBox *SystemTrayQueryCloseCheckBox;
    QCheckBox *StartMinimizedCheckBox;
    QSpacerItem *spacerItem2;
    QWidget *DisplayTabPage;
    QVBoxLayout *vboxLayout2;
    QGroupBox *KnobsGroupBox;
    QGridLayout *gridLayout2;
    QLabel *KnobStyleTextLabel;
    QComboBox *KnobStyleComboBox;
    QSpacerItem *spacerItem3;
    QLabel *KnobMouseMotionTextLabel;
    QComboBox *KnobMouseMotionComboBox;
    QGroupBox *CustomGroupBox;
    QGridLayout *gridLayout3;
    QLabel *CustomColorThemeTextLabel;
    QComboBox *CustomColorThemeComboBox;
    QToolButton *CustomColorThemeToolButton;
    QSpacerItem *spacerItem4;
    QLabel *CustomStyleThemeTextLabel;
    QComboBox *CustomStyleThemeComboBox;
    QGroupBox *DefaultsGroupBox;
    QGridLayout *gridLayout4;
    QSpacerItem *spacerItem5;
    QLabel *BaseFontSizeTextLabel;
    QComboBox *BaseFontSizeComboBox;
    QSpacerItem *spacerItem6;
    QDialogButtonBox *DialogButtonBox;

    void setupUi(QDialog *qsynthOptionsForm)
    {
        if (qsynthOptionsForm->objectName().isEmpty())
            qsynthOptionsForm->setObjectName("qsynthOptionsForm");
        qsynthOptionsForm->resize(555, 389);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/options1.png"));
        qsynthOptionsForm->setWindowIcon(icon);
        qsynthOptionsForm->setSizeGripEnabled(true);
        vboxLayout = new QVBoxLayout(qsynthOptionsForm);
        vboxLayout->setSpacing(4);
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        OptionsTabWidget = new QTabWidget(qsynthOptionsForm);
        OptionsTabWidget->setObjectName("OptionsTabWidget");
        GeneralTabPage = new QWidget();
        GeneralTabPage->setObjectName("GeneralTabPage");
        vboxLayout1 = new QVBoxLayout(GeneralTabPage);
        vboxLayout1->setSpacing(4);
        vboxLayout1->setContentsMargins(8, 8, 8, 8);
        vboxLayout1->setObjectName("vboxLayout1");
        MessagesGroupBox = new QGroupBox(GeneralTabPage);
        MessagesGroupBox->setObjectName("MessagesGroupBox");
        QFont font;
        font.setBold(true);
        MessagesGroupBox->setFont(font);
        MessagesGroupBox->setFlat(true);
        hboxLayout = new QHBoxLayout(MessagesGroupBox);
        hboxLayout->setSpacing(4);
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout->setObjectName("hboxLayout");
        MessagesFontTextLabel = new QLabel(MessagesGroupBox);
        MessagesFontTextLabel->setObjectName("MessagesFontTextLabel");
        MessagesFontTextLabel->setMinimumSize(QSize(180, 0));
        MessagesFontTextLabel->setMaximumSize(QSize(180, 32767));
        QFont font1;
        font1.setBold(false);
        MessagesFontTextLabel->setFont(font1);
        MessagesFontTextLabel->setAutoFillBackground(true);
        MessagesFontTextLabel->setFrameShape(QFrame::StyledPanel);
        MessagesFontTextLabel->setFrameShadow(QFrame::Sunken);
        MessagesFontTextLabel->setAlignment(Qt::AlignCenter);
        MessagesFontTextLabel->setWordWrap(false);

        hboxLayout->addWidget(MessagesFontTextLabel);

        MessagesFontPushButton = new QPushButton(MessagesGroupBox);
        MessagesFontPushButton->setObjectName("MessagesFontPushButton");
        MessagesFontPushButton->setFont(font1);
        MessagesFontPushButton->setAutoDefault(false);

        hboxLayout->addWidget(MessagesFontPushButton);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        MessagesLimitCheckBox = new QCheckBox(MessagesGroupBox);
        MessagesLimitCheckBox->setObjectName("MessagesLimitCheckBox");
        MessagesLimitCheckBox->setFont(font1);

        hboxLayout->addWidget(MessagesLimitCheckBox);

        MessagesLimitLinesComboBox = new QComboBox(MessagesGroupBox);
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->addItem(QString());
        MessagesLimitLinesComboBox->setObjectName("MessagesLimitLinesComboBox");
        MessagesLimitLinesComboBox->setFont(font1);
        MessagesLimitLinesComboBox->setEditable(true);

        hboxLayout->addWidget(MessagesLimitLinesComboBox);


        vboxLayout1->addWidget(MessagesGroupBox);

        LoggingGroupBox = new QGroupBox(GeneralTabPage);
        LoggingGroupBox->setObjectName("LoggingGroupBox");
        LoggingGroupBox->setFont(font);
        LoggingGroupBox->setFlat(true);
        gridLayout = new QGridLayout(LoggingGroupBox);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        MessagesLogPathComboBox = new QComboBox(LoggingGroupBox);
        MessagesLogPathComboBox->setObjectName("MessagesLogPathComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MessagesLogPathComboBox->sizePolicy().hasHeightForWidth());
        MessagesLogPathComboBox->setSizePolicy(sizePolicy);
        MessagesLogPathComboBox->setFont(font1);
        MessagesLogPathComboBox->setEditable(true);

        gridLayout->addWidget(MessagesLogPathComboBox, 0, 1, 1, 3);

        MessagesLogPathToolButton = new QToolButton(LoggingGroupBox);
        MessagesLogPathToolButton->setObjectName("MessagesLogPathToolButton");
        MessagesLogPathToolButton->setMinimumSize(QSize(22, 22));
        MessagesLogPathToolButton->setMaximumSize(QSize(24, 24));
        MessagesLogPathToolButton->setFont(font1);
        MessagesLogPathToolButton->setFocusPolicy(Qt::TabFocus);

        gridLayout->addWidget(MessagesLogPathToolButton, 0, 4, 1, 1);

        MessagesLogCheckBox = new QCheckBox(LoggingGroupBox);
        MessagesLogCheckBox->setObjectName("MessagesLogCheckBox");
        MessagesLogCheckBox->setFont(font1);

        gridLayout->addWidget(MessagesLogCheckBox, 0, 0, 1, 1);


        vboxLayout1->addWidget(LoggingGroupBox);

        OtherGroupBox = new QGroupBox(GeneralTabPage);
        OtherGroupBox->setObjectName("OtherGroupBox");
        OtherGroupBox->setFont(font);
        OtherGroupBox->setFlat(true);
        gridLayout1 = new QGridLayout(OtherGroupBox);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName("gridLayout1");
        QueryCloseCheckBox = new QCheckBox(OtherGroupBox);
        QueryCloseCheckBox->setObjectName("QueryCloseCheckBox");
        QueryCloseCheckBox->setFont(font1);

        gridLayout1->addWidget(QueryCloseCheckBox, 0, 0, 1, 1);

        KeepOnTopCheckBox = new QCheckBox(OtherGroupBox);
        KeepOnTopCheckBox->setObjectName("KeepOnTopCheckBox");
        KeepOnTopCheckBox->setFont(font1);

        gridLayout1->addWidget(KeepOnTopCheckBox, 1, 0, 1, 1);

        StdoutCaptureCheckBox = new QCheckBox(OtherGroupBox);
        StdoutCaptureCheckBox->setObjectName("StdoutCaptureCheckBox");
        StdoutCaptureCheckBox->setFont(font1);

        gridLayout1->addWidget(StdoutCaptureCheckBox, 2, 0, 1, 1);

        OutputMetersCheckBox = new QCheckBox(OtherGroupBox);
        OutputMetersCheckBox->setObjectName("OutputMetersCheckBox");
        OutputMetersCheckBox->setFont(font1);

        gridLayout1->addWidget(OutputMetersCheckBox, 3, 0, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 1, 4, 1);

        SystemTrayCheckBox = new QCheckBox(OtherGroupBox);
        SystemTrayCheckBox->setObjectName("SystemTrayCheckBox");
        SystemTrayCheckBox->setFont(font1);

        gridLayout1->addWidget(SystemTrayCheckBox, 0, 2, 1, 1);

        SystemTrayQueryCloseCheckBox = new QCheckBox(OtherGroupBox);
        SystemTrayQueryCloseCheckBox->setObjectName("SystemTrayQueryCloseCheckBox");
        SystemTrayQueryCloseCheckBox->setFont(font1);

        gridLayout1->addWidget(SystemTrayQueryCloseCheckBox, 1, 2, 1, 1);

        StartMinimizedCheckBox = new QCheckBox(OtherGroupBox);
        StartMinimizedCheckBox->setObjectName("StartMinimizedCheckBox");
        StartMinimizedCheckBox->setFont(font1);

        gridLayout1->addWidget(StartMinimizedCheckBox, 2, 2, 1, 1);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem2, 4, 0, 1, 3);


        vboxLayout1->addWidget(OtherGroupBox);

        OptionsTabWidget->addTab(GeneralTabPage, QString());
        DisplayTabPage = new QWidget();
        DisplayTabPage->setObjectName("DisplayTabPage");
        vboxLayout2 = new QVBoxLayout(DisplayTabPage);
        vboxLayout2->setSpacing(4);
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        vboxLayout2->setObjectName("vboxLayout2");
        KnobsGroupBox = new QGroupBox(DisplayTabPage);
        KnobsGroupBox->setObjectName("KnobsGroupBox");
        KnobsGroupBox->setFont(font);
        KnobsGroupBox->setFlat(true);
        gridLayout2 = new QGridLayout(KnobsGroupBox);
        gridLayout2->setSpacing(4);
        gridLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout2->setObjectName("gridLayout2");
        KnobStyleTextLabel = new QLabel(KnobsGroupBox);
        KnobStyleTextLabel->setObjectName("KnobStyleTextLabel");
        KnobStyleTextLabel->setFont(font1);

        gridLayout2->addWidget(KnobStyleTextLabel, 0, 0, 1, 1);

        KnobStyleComboBox = new QComboBox(KnobsGroupBox);
        KnobStyleComboBox->addItem(QString());
        KnobStyleComboBox->addItem(QString());
        KnobStyleComboBox->addItem(QString());
        KnobStyleComboBox->addItem(QString());
        KnobStyleComboBox->addItem(QString());
        KnobStyleComboBox->setObjectName("KnobStyleComboBox");
        KnobStyleComboBox->setFont(font1);

        gridLayout2->addWidget(KnobStyleComboBox, 0, 1, 1, 1);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem3, 0, 2, 1, 1);

        KnobMouseMotionTextLabel = new QLabel(KnobsGroupBox);
        KnobMouseMotionTextLabel->setObjectName("KnobMouseMotionTextLabel");
        KnobMouseMotionTextLabel->setFont(font1);
        KnobMouseMotionTextLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(KnobMouseMotionTextLabel, 0, 3, 1, 1);

        KnobMouseMotionComboBox = new QComboBox(KnobsGroupBox);
        KnobMouseMotionComboBox->addItem(QString());
        KnobMouseMotionComboBox->addItem(QString());
        KnobMouseMotionComboBox->addItem(QString());
        KnobMouseMotionComboBox->setObjectName("KnobMouseMotionComboBox");
        KnobMouseMotionComboBox->setFont(font1);

        gridLayout2->addWidget(KnobMouseMotionComboBox, 0, 4, 1, 1);


        vboxLayout2->addWidget(KnobsGroupBox);

        CustomGroupBox = new QGroupBox(DisplayTabPage);
        CustomGroupBox->setObjectName("CustomGroupBox");
        CustomGroupBox->setFont(font);
        CustomGroupBox->setFlat(true);
        gridLayout3 = new QGridLayout(CustomGroupBox);
        gridLayout3->setSpacing(4);
        gridLayout3->setContentsMargins(8, 8, 8, 8);
        gridLayout3->setObjectName("gridLayout3");
        CustomColorThemeTextLabel = new QLabel(CustomGroupBox);
        CustomColorThemeTextLabel->setObjectName("CustomColorThemeTextLabel");
        CustomColorThemeTextLabel->setFont(font1);
        CustomColorThemeTextLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout3->addWidget(CustomColorThemeTextLabel, 0, 0, 1, 1);

        CustomColorThemeComboBox = new QComboBox(CustomGroupBox);
        CustomColorThemeComboBox->addItem(QString());
        CustomColorThemeComboBox->addItem(QString());
        CustomColorThemeComboBox->addItem(QString());
        CustomColorThemeComboBox->setObjectName("CustomColorThemeComboBox");
        CustomColorThemeComboBox->setFont(font1);
        CustomColorThemeComboBox->setEditable(false);

        gridLayout3->addWidget(CustomColorThemeComboBox, 0, 1, 1, 1);

        CustomColorThemeToolButton = new QToolButton(CustomGroupBox);
        CustomColorThemeToolButton->setObjectName("CustomColorThemeToolButton");
        CustomColorThemeToolButton->setMinimumSize(QSize(22, 22));
        CustomColorThemeToolButton->setMaximumSize(QSize(24, 24));
        CustomColorThemeToolButton->setFont(font1);
        CustomColorThemeToolButton->setFocusPolicy(Qt::TabFocus);

        gridLayout3->addWidget(CustomColorThemeToolButton, 0, 3, 1, 1);

        spacerItem4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem4, 0, 4, 1, 1);

        CustomStyleThemeTextLabel = new QLabel(CustomGroupBox);
        CustomStyleThemeTextLabel->setObjectName("CustomStyleThemeTextLabel");
        CustomStyleThemeTextLabel->setFont(font1);

        gridLayout3->addWidget(CustomStyleThemeTextLabel, 0, 5, 1, 1);

        CustomStyleThemeComboBox = new QComboBox(CustomGroupBox);
        CustomStyleThemeComboBox->addItem(QString());
        CustomStyleThemeComboBox->setObjectName("CustomStyleThemeComboBox");
        CustomStyleThemeComboBox->setFont(font1);
        CustomStyleThemeComboBox->setEditable(false);

        gridLayout3->addWidget(CustomStyleThemeComboBox, 0, 6, 1, 1);


        vboxLayout2->addWidget(CustomGroupBox);

        DefaultsGroupBox = new QGroupBox(DisplayTabPage);
        DefaultsGroupBox->setObjectName("DefaultsGroupBox");
        DefaultsGroupBox->setFont(font);
        DefaultsGroupBox->setFlat(true);
        gridLayout4 = new QGridLayout(DefaultsGroupBox);
        gridLayout4->setSpacing(4);
        gridLayout4->setContentsMargins(8, 8, 8, 8);
        gridLayout4->setObjectName("gridLayout4");
        spacerItem5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout4->addItem(spacerItem5, 0, 0, 1, 3);

        BaseFontSizeTextLabel = new QLabel(DefaultsGroupBox);
        BaseFontSizeTextLabel->setObjectName("BaseFontSizeTextLabel");
        BaseFontSizeTextLabel->setFont(font1);
        BaseFontSizeTextLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout4->addWidget(BaseFontSizeTextLabel, 0, 3, 1, 1);

        BaseFontSizeComboBox = new QComboBox(DefaultsGroupBox);
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->addItem(QString());
        BaseFontSizeComboBox->setObjectName("BaseFontSizeComboBox");
        BaseFontSizeComboBox->setFont(font1);
        BaseFontSizeComboBox->setEditable(true);

        gridLayout4->addWidget(BaseFontSizeComboBox, 0, 4, 1, 1);

        spacerItem6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout4->addItem(spacerItem6, 1, 0, 1, 5);


        vboxLayout2->addWidget(DefaultsGroupBox);

        OptionsTabWidget->addTab(DisplayTabPage, QString());

        vboxLayout->addWidget(OptionsTabWidget);

        DialogButtonBox = new QDialogButtonBox(qsynthOptionsForm);
        DialogButtonBox->setObjectName("DialogButtonBox");
        DialogButtonBox->setOrientation(Qt::Horizontal);
        DialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(DialogButtonBox);

#if QT_CONFIG(shortcut)
        KnobStyleTextLabel->setBuddy(KnobStyleComboBox);
        KnobMouseMotionTextLabel->setBuddy(KnobMouseMotionComboBox);
        CustomColorThemeTextLabel->setBuddy(CustomColorThemeComboBox);
        CustomStyleThemeTextLabel->setBuddy(CustomStyleThemeComboBox);
        BaseFontSizeTextLabel->setBuddy(BaseFontSizeComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(OptionsTabWidget, KnobStyleComboBox);
        QWidget::setTabOrder(KnobStyleComboBox, KnobMouseMotionComboBox);
        QWidget::setTabOrder(KnobMouseMotionComboBox, CustomColorThemeComboBox);
        QWidget::setTabOrder(CustomColorThemeComboBox, CustomColorThemeToolButton);
        QWidget::setTabOrder(CustomColorThemeToolButton, CustomStyleThemeComboBox);
        QWidget::setTabOrder(CustomStyleThemeComboBox, BaseFontSizeComboBox);
        QWidget::setTabOrder(BaseFontSizeComboBox, DialogButtonBox);

        retranslateUi(qsynthOptionsForm);

        OptionsTabWidget->setCurrentIndex(0);
        MessagesLimitLinesComboBox->setCurrentIndex(3);
        KnobMouseMotionComboBox->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(qsynthOptionsForm);
    } // setupUi

    void retranslateUi(QDialog *qsynthOptionsForm)
    {
        qsynthOptionsForm->setWindowTitle(QCoreApplication::translate("qsynthOptionsForm", "Options", nullptr));
        MessagesGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Messages", nullptr));
#if QT_CONFIG(tooltip)
        MessagesFontTextLabel->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Sample messages text font display", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        MessagesFontPushButton->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Select font for the messages text display", nullptr));
#endif // QT_CONFIG(tooltip)
        MessagesFontPushButton->setText(QCoreApplication::translate("qsynthOptionsForm", "&Font...", nullptr));
#if QT_CONFIG(tooltip)
        MessagesLimitCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to keep a maximum number of lines in the messages window", nullptr));
#endif // QT_CONFIG(tooltip)
        MessagesLimitCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "&Messages limit:", nullptr));
        MessagesLimitLinesComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "100", nullptr));
        MessagesLimitLinesComboBox->setItemText(1, QCoreApplication::translate("qsynthOptionsForm", "250", nullptr));
        MessagesLimitLinesComboBox->setItemText(2, QCoreApplication::translate("qsynthOptionsForm", "500", nullptr));
        MessagesLimitLinesComboBox->setItemText(3, QCoreApplication::translate("qsynthOptionsForm", "1000", nullptr));
        MessagesLimitLinesComboBox->setItemText(4, QCoreApplication::translate("qsynthOptionsForm", "2500", nullptr));
        MessagesLimitLinesComboBox->setItemText(5, QCoreApplication::translate("qsynthOptionsForm", "5000", nullptr));

#if QT_CONFIG(tooltip)
        MessagesLimitLinesComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "The maximum number of message lines to keep in view", nullptr));
#endif // QT_CONFIG(tooltip)
        LoggingGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Logging", nullptr));
#if QT_CONFIG(tooltip)
        MessagesLogPathComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Messages log file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        MessagesLogPathToolButton->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Browse for the messages log file location", nullptr));
#endif // QT_CONFIG(tooltip)
        MessagesLogPathToolButton->setText(QCoreApplication::translate("qsynthOptionsForm", "...", nullptr));
#if QT_CONFIG(tooltip)
        MessagesLogCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to activate a messages logging to file.", nullptr));
#endif // QT_CONFIG(tooltip)
        MessagesLogCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "Messages &log file:", nullptr));
        OtherGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Other", nullptr));
#if QT_CONFIG(tooltip)
        QueryCloseCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to ask for confirmation on application exit", nullptr));
#endif // QT_CONFIG(tooltip)
        QueryCloseCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "&Confirm application close", nullptr));
#if QT_CONFIG(tooltip)
        KeepOnTopCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to keep all child windows on top of the main window", nullptr));
#endif // QT_CONFIG(tooltip)
        KeepOnTopCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "&Keep child windows always on top", nullptr));
#if QT_CONFIG(tooltip)
        StdoutCaptureCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to capture standard output (stdout/stderr) into messages window", nullptr));
#endif // QT_CONFIG(tooltip)
        StdoutCaptureCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "Capture standard &output", nullptr));
#if QT_CONFIG(tooltip)
        OutputMetersCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to monitor and show engine output peak level meters", nullptr));
#endif // QT_CONFIG(tooltip)
        OutputMetersCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "Output &peak level meters", nullptr));
#if QT_CONFIG(tooltip)
        SystemTrayCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to enable the system tray icon", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemTrayCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "&Enable system tray icon", nullptr));
#if QT_CONFIG(tooltip)
        SystemTrayQueryCloseCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to show system tray message on main window close", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemTrayQueryCloseCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "Sho&w system tray message on close", nullptr));
#if QT_CONFIG(tooltip)
        StartMinimizedCheckBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Whether to start minimized to system tray", nullptr));
#endif // QT_CONFIG(tooltip)
        StartMinimizedCheckBox->setText(QCoreApplication::translate("qsynthOptionsForm", "Start minimi&zed to system tray", nullptr));
        OptionsTabWidget->setTabText(OptionsTabWidget->indexOf(GeneralTabPage), QCoreApplication::translate("qsynthOptionsForm", "General", nullptr));
        KnobsGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Knobs", nullptr));
        KnobStyleTextLabel->setText(QCoreApplication::translate("qsynthOptionsForm", "Kno&b graphic style:", nullptr));
        KnobStyleComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "Classic", nullptr));
        KnobStyleComboBox->setItemText(1, QCoreApplication::translate("qsynthOptionsForm", "Vokimon", nullptr));
        KnobStyleComboBox->setItemText(2, QCoreApplication::translate("qsynthOptionsForm", "Peppino", nullptr));
        KnobStyleComboBox->setItemText(3, QCoreApplication::translate("qsynthOptionsForm", "Skulpture", nullptr));
        KnobStyleComboBox->setItemText(4, QCoreApplication::translate("qsynthOptionsForm", "Legacy", nullptr));

#if QT_CONFIG(tooltip)
        KnobStyleComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Graphic style for knobs", nullptr));
#endif // QT_CONFIG(tooltip)
        KnobMouseMotionTextLabel->setText(QCoreApplication::translate("qsynthOptionsForm", "Mouse motion be&havior:", nullptr));
        KnobMouseMotionComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "Legacy", nullptr));
        KnobMouseMotionComboBox->setItemText(1, QCoreApplication::translate("qsynthOptionsForm", "Radial", nullptr));
        KnobMouseMotionComboBox->setItemText(2, QCoreApplication::translate("qsynthOptionsForm", "Linear", nullptr));

#if QT_CONFIG(tooltip)
        KnobMouseMotionComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Mouse motion behavior for knobs", nullptr));
#endif // QT_CONFIG(tooltip)
        CustomGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Custom", nullptr));
        CustomColorThemeTextLabel->setText(QCoreApplication::translate("qsynthOptionsForm", "&Color palette theme:", nullptr));
        CustomColorThemeComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "(default)", nullptr));
        CustomColorThemeComboBox->setItemText(1, QCoreApplication::translate("qsynthOptionsForm", "Wonton Soup", nullptr));
        CustomColorThemeComboBox->setItemText(2, QCoreApplication::translate("qsynthOptionsForm", "KXStudio", nullptr));

#if QT_CONFIG(tooltip)
        CustomColorThemeComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Custom color palette theme", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        CustomColorThemeToolButton->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Manage custom color palette themes", nullptr));
#endif // QT_CONFIG(tooltip)
        CustomColorThemeToolButton->setText(QCoreApplication::translate("qsynthOptionsForm", "...", nullptr));
        CustomStyleThemeTextLabel->setText(QCoreApplication::translate("qsynthOptionsForm", "&Widget style theme:", nullptr));
        CustomStyleThemeComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "(default)", nullptr));

#if QT_CONFIG(tooltip)
        CustomStyleThemeComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Custom widget style theme", nullptr));
#endif // QT_CONFIG(tooltip)
        DefaultsGroupBox->setTitle(QCoreApplication::translate("qsynthOptionsForm", "Defaults", nullptr));
        BaseFontSizeTextLabel->setText(QCoreApplication::translate("qsynthOptionsForm", "&Base font size:", nullptr));
        BaseFontSizeComboBox->setItemText(0, QCoreApplication::translate("qsynthOptionsForm", "(default)", nullptr));
        BaseFontSizeComboBox->setItemText(1, QCoreApplication::translate("qsynthOptionsForm", "6", nullptr));
        BaseFontSizeComboBox->setItemText(2, QCoreApplication::translate("qsynthOptionsForm", "7", nullptr));
        BaseFontSizeComboBox->setItemText(3, QCoreApplication::translate("qsynthOptionsForm", "8", nullptr));
        BaseFontSizeComboBox->setItemText(4, QCoreApplication::translate("qsynthOptionsForm", "9", nullptr));
        BaseFontSizeComboBox->setItemText(5, QCoreApplication::translate("qsynthOptionsForm", "10", nullptr));
        BaseFontSizeComboBox->setItemText(6, QCoreApplication::translate("qsynthOptionsForm", "11", nullptr));
        BaseFontSizeComboBox->setItemText(7, QCoreApplication::translate("qsynthOptionsForm", "12", nullptr));

#if QT_CONFIG(tooltip)
        BaseFontSizeComboBox->setToolTip(QCoreApplication::translate("qsynthOptionsForm", "Base application font size (pt.)", nullptr));
#endif // QT_CONFIG(tooltip)
        OptionsTabWidget->setTabText(OptionsTabWidget->indexOf(DisplayTabPage), QCoreApplication::translate("qsynthOptionsForm", "Display", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qsynthOptionsForm: public Ui_qsynthOptionsForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSYNTHOPTIONSFORM_H
